@@ -25,7 +25,8 @@ class ParticleDistributionCMS:
         print("Starting event processing")
         
         for evn_num in sim_numbers:
-            print("Working on event " + i)
+            if i % 1000 == 0:
+                print("Working on event " + str(i))
             
             self.event_list.append(np.asarray(sim.particles[sim.jets_i[:,sim.evn]==evn_num]))
             self.event_jet_labels.append(np.asarray(sim.hard_pids[sim.jets_i[:,sim.evn]==evn_num]))
@@ -35,7 +36,8 @@ class ParticleDistributionCMS:
             self.event_phis.append(np.asarray(sim.jet_phis[sim.jets_i[:,sim.evn]==evn_num]))
             self.event_ms.append(np.asarray(sim.jet_ms[sim.jets_i[:,sim.evn]==evn_num]))
 
-            print(i + " events processed")
+            if i % 1000 == 0:
+                print(str(i) + " events processed")
 
             i += 1
 
@@ -60,8 +62,8 @@ class ParticleDistributionCMS:
         
                 self.event_stats[i].append(p4s.tolist())
 
-            
-            print(i + " event masses calculated")
+            if i % 1000 == 0:
+                print(str(i) + " event masses calculated")
                 
             i += 1
         
